# Changelog

All notable changes to this project will be documented in this file.
## v2604.2.0
- Added suggestions for failure due to typos in the dependency flows.
- Added `broadcast` option to avoid splitting results for array jobs.
- Added local job execution mode without workload manager.
## v2604.1.0
- `@job` decorator can spawn array jobs.
## v2604.0.1
- Initial release
